import os
import numpy as np
import math
import iris
import iris.cube
import iris.analysis
import warnings
import numba
import datetime
from numba import jit, njit
from numba import vectorize
from numba import guvectorize
from numba import cuda
from numba import int32, int64, float32, float64
from numba.cuda.cudadrv import driver

VSFTMYZ_FILE = '/esarchive/exp/ecearth/a16l/cmorfiles/CMIP'\
               '/EC-Earth-Consortium/EC-Earth3-LR/historical/r1i1p1f1/Omon'\
               '/vsftmyz/gn/v20180711/vsftmyz_Omon_EC-Earth3-LR_historical_'\
               'r1i1p1f1_gn_196101-196112.nc'

def main():
    one_layer = ((0, 300),)
    vsftmyz = load_vsftmyz()



def load_vsftmyz():
    long_name = 'Ocean meridional overturning volume streamfunction'
    vsftmyz = iris.load_cube(VSFTMYZ_FILE, long_name)
    vsftmyz_data = np.ma.filled(vsftmyz.data, 0.0).astype(np.float32)
    return vsftmyz_data


@vectorize(['float32(int32, int32, float32, float32, float32)'], target='cpu')
def calculate_vweight_numba(min_depth, max_depth, e3t, depth, mask):
    """
    Calculates the weight for each cell
    """
    if not mask:
        return 0
    top = depth
    bottom = top + e3t
    if bottom < min_depth or top > max_depth:
        return 0
    else:
        if top < min_depth:
            top = min_depth
        if bottom > max_depth:
            bottom = max_depth

        return (bottom - top)


@vectorize(['float32(int32, int32, float32, float32, float32)'], target='cpu')
def calculate_hweight_numba(west_lat, east_lat, e1v, lat, mask):
    """
    Calculates the weight for each cell
    """
    if not mask:
        return 0
    west = depth
    bottom = top + e1v
    if bottom < min_depth or top > max_depth:
        return 0
    else:
        if top < min_depth:
            top = min_depth
        if bottom > max_depth:
            bottom = max_depth

        return math.cos(bottom - top)


if __name__ == '__main__':
    main()
